(function ($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.micro_sso = Drupal.behaviors.micro_sso || {};
  Drupal.behaviors.micro_sso.attach = function (context) {
    if (Drupal.behaviors.micro_sso.may()) {
      Drupal.behaviors.micro_sso.check();
    }
  };

  // Tell the browser to stop checking for a while.
  Drupal.behaviors.micro_sso.stop = function () {
    var time = Math.floor(Date.now() / 1000) + 600; // 10 minutes.
    $.cookie('micro_sso', time);
  };

  // Can the browser attempt to login ?
  Drupal.behaviors.micro_sso.may = function () {
    var now = Math.floor(Date.now() / 1000); // 10 minutes.
    var stop = $.cookie('micro_sso');
    return !stop || stop < now;
  };

  /**
   * Check on the master if user can log in and the micro site is valid.
   *
   * Gets an uri with a token if user is logged in on the master and then uses
   * it on the micro site to log user in.
   */
  Drupal.behaviors.micro_sso.check = function () {
    $.ajax(drupalSettings.micro_sso.master, {
      'crossDomain': true,
      'data': {
        "origin": window.location.origin
      },
      'method': 'GET',
      'headers': {
        "Accept": "application/json"
      },
      'xhrFields': {
        'withCredentials': true
      }
    }).done(Drupal.behaviors.micro_sso.login);
  };

  /**
   * Login the user on the micro site.
   */
  Drupal.behaviors.micro_sso.login = function (data) {
    if (data.status === 1 && data.uri) {
      $.ajax(data.uri, {
        'crossDomain': true,
        'data': {
          "origin": window.location.origin
        },
        'headers': {
          "Accept": "application/json"
        },
        'method': 'GET',
        'xhrFields': {
          'withCredentials': true
        }
      }).done(Drupal.behaviors.micro_sso.finalize);
    }
    else {
      Drupal.behaviors.micro_sso.stop();
    }

  };

  /**
   * Reload the page in case of a successful login.
   */
  Drupal.behaviors.micro_sso.finalize = function (data) {
    // Don't retry before 10 min.
    Drupal.behaviors.micro_sso.stop();
    if (data.success === true) {
      if (data.destination) {
        window.location.href = data.destination;
      }
      else {
        window.location.reload();
      }
    }
  };


})(jQuery, Drupal, drupalSettings);
